==> libakonadi-19.03.90-2-x86_64.pkg.tar.xz: usr/lib/cmake/KF5Akonadi/KF5AkonadiConfig.cmake <==

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was KF5AkonadiConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/cmake/KF5Akonadi" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

# set the directories
if(NOT AKONADI_INSTALL_DIR)
   set(AKONADI_INSTALL_DIR "/usr")
endif(NOT AKONADI_INSTALL_DIR)
include(CMakeFindDependencyMacro)
find_dependency(KF5Completion "")
find_dependency(KF5XmlGui "")
find_dependency(KF5ItemModels "")
find_dependency(KF5ConfigWidgets "")

find_dependency(Qt5DBus "5.10.0")
find_dependency(Qt5Network "5.10.0")

set_and_check(AKONADI_DBUS_INTERFACES_DIR  "${PACKAGE_PREFIX_DIR}/share/dbus-1/interfaces")
set_and_check(AKONADI_INCLUDE_DIR          "${PACKAGE_PREFIX_DIR}/include/KF5")

find_dependency(Boost "1.34.0")

include(${CMAKE_CURRENT_LIST_DIR}/KF5AkonadiTargets.cmake)
include(${CMAKE_CURRENT_LIST_DIR}/KF5AkonadiMacros.cmake)

# The directory where akonadi-xml.xsd and kcfg2dbus.xsl are installed
set(KF5Akonadi_DATA_DIR "${PACKAGE_PREFIX_DIR}/share/kf5/akonadi")

####################################################################################
# CMAKE_AUTOMOC

if(NOT CMAKE_VERSION VERSION_LESS "3.10.0")
    # CMake 3.9+ warns about automoc on files without Q_OBJECT, and doesn't know about other macros.
    # 3.10+ lets us provide more macro names that require automoc.
    list(APPEND CMAKE_AUTOMOC_MACRO_NAMES AKONADI_AGENTCONFIG_FACTORY)
endif()

==> libakonadi-19.04.0-2-x86_64.pkg.tar.xz: usr/lib/cmake/KF5Akonadi/KF5AkonadiConfig.cmake <==

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was KF5AkonadiConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/cmake/KF5Akonadi" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

# set the directories
if(NOT AKONADI_INSTALL_DIR)
   set(AKONADI_INSTALL_DIR "/usr")
endif(NOT AKONADI_INSTALL_DIR)
include(CMakeFindDependencyMacro)
find_dependency(KF5Completion "5.56.0")
find_dependency(KF5XmlGui "5.56.0")
find_dependency(KF5ItemModels "5.56.0")
find_dependency(KF5ConfigWidgets "5.56.0")

find_dependency(Qt5DBus "5.10.0")
find_dependency(Qt5Network "5.10.0")

set_and_check(AKONADI_DBUS_INTERFACES_DIR  "${PACKAGE_PREFIX_DIR}/share/dbus-1/interfaces")
set_and_check(AKONADI_INCLUDE_DIR          "${PACKAGE_PREFIX_DIR}/include/KF5")

find_dependency(Boost "1.34.0")

include(${CMAKE_CURRENT_LIST_DIR}/KF5AkonadiTargets.cmake)
include(${CMAKE_CURRENT_LIST_DIR}/KF5AkonadiMacros.cmake)

# The directory where akonadi-xml.xsd and kcfg2dbus.xsl are installed
set(KF5Akonadi_DATA_DIR "${PACKAGE_PREFIX_DIR}/share/kf5/akonadi")

####################################################################################
# CMAKE_AUTOMOC

if(NOT CMAKE_VERSION VERSION_LESS "3.10.0")
    # CMake 3.9+ warns about automoc on files without Q_OBJECT, and doesn't know about other macros.
    # 3.10+ lets us provide more macro names that require automoc.
    list(APPEND CMAKE_AUTOMOC_MACRO_NAMES AKONADI_AGENTCONFIG_FACTORY)
endif()
